==> libksieve-22.08.1.tgz: lib/cmake/KF5LibKSieve/KF5LibKSieveTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KManageSieve" for configuration "Release"
set_property(TARGET KF5::KManageSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::KManageSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::KIOCore;KF5::KIOWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5KManageSieve.so.1.0"
  )

list(APPEND _cmake_import_check_targets KF5::KManageSieve )
list(APPEND _cmake_import_check_files_for_KF5::KManageSieve "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.1.0" )

# Import target "KF5::KSieveUi" for configuration "Release"
set_property(TARGET KF5::KSieveUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::KSieveUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::Libkdepim;KF5::Archive;KF5::Mime;KF5::IconThemes;KF5::IdentityManagement;KF5::PimTextEdit;KF5::MailTransport;KF5::KIOWidgets;KF5::NewStuff;Qt5::WebEngineWidgets;KF5::I18n;KF5::SonnetUi;Qt5::PrintSupport;KF5::SyntaxHighlighting"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.0"
  IMPORTED_SONAME_RELEASE "libKF5KSieveUi.so.5.0"
  )

list(APPEND _cmake_import_check_targets KF5::KSieveUi )
list(APPEND _cmake_import_check_files_for_KF5::KSieveUi "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.0" )

# Import target "KF5::KSieve" for configuration "Release"
set_property(TARGET KF5::KSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::KSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Core;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5KSieve.so.1.0"
  )

list(APPEND _cmake_import_check_targets KF5::KSieve )
list(APPEND _cmake_import_check_files_for_KF5::KSieve "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libksieve-22.12.3.tgz: lib/cmake/KF5LibKSieve/KF5LibKSieveTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KManageSieve" for configuration "Release"
set_property(TARGET KF5::KManageSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::KManageSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n;KF5::KIOCore;KF5::KIOWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5KManageSieve.so.1.0"
  )

list(APPEND _cmake_import_check_targets KF5::KManageSieve )
list(APPEND _cmake_import_check_files_for_KF5::KManageSieve "${_IMPORT_PREFIX}/lib/libKF5KManageSieve.so.1.0" )

# Import target "KF5::KSieveUi" for configuration "Release"
set_property(TARGET KF5::KSieveUi APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::KSieveUi PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::Libkdepim;KF5::Archive;KF5::Mime;KF5::IconThemes;KF5::IdentityManagement;KF5::PimTextEdit;KF5::MailTransport;KF5::KIOWidgets;KF5::NewStuff;KF5::I18n;KF5::SonnetUi;KF5::SyntaxHighlighting"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.0"
  IMPORTED_SONAME_RELEASE "libKF5KSieveUi.so.5.0"
  )

list(APPEND _cmake_import_check_targets KF5::KSieveUi )
list(APPEND _cmake_import_check_files_for_KF5::KSieveUi "${_IMPORT_PREFIX}/lib/libKF5KSieveUi.so.5.0" )

# Import target "KF5::KSieve" for configuration "Release"
set_property(TARGET KF5::KSieve APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::KSieve PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.1.0"
  IMPORTED_SONAME_RELEASE "libKF5KSieve.so.1.0"
  )

list(APPEND _cmake_import_check_targets KF5::KSieve )
list(APPEND _cmake_import_check_files_for_KF5::KSieve "${_IMPORT_PREFIX}/lib/libKF5KSieve.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
